from setuptools import find_packages, setup


setup(
    name='fldataparser',
    version='0.0.3',
    description='parser tool for object send through rabbitmq in FLExplorer',
    packages=find_packages()
)
